#[non_exhaustive]
pub struct Config<'c> { pub seed: FeatureSet<'c>, pub include: FeatureSet<'c>, pub deny: FeatureSet<'c>, pub skip: FeatureMatrix<'c>, pub include_hidden: bool, pub conflict: HashSet<FeatureSet<'c>>, }

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
seed: FeatureSet<'c>

If this set is not empty, only these features will be used to construct the matrix.

include: FeatureSet<'c>

All of these features will be included in every feature set in the matrix.

deny: FeatureSet<'c>

Any feature set that includes any of these will be excluded from the matrix. This includes features enabled by other features.

This can be used for things like having an “__unstable” feature that gets enabled by any other features that use unstable rust features and then excluding “__unstable” if not on nightly.

skip: FeatureMatrix<'c>

These sets will be dropped from the matrix.

include_hidden: bool

Some crates prepend internal features with a double underscore. If this flag is not set, those features will not be used to build the matrix, but will be allowed if they are enabled by other features.

conflict: HashSet<FeatureSet<'c>>

List sets of features that can’t be used together. Any generated feature set that is a superset of any of these sets will be dropped from the matrix.

Implementations