pub struct Feature<'f>(/* private fields */);Methods from Deref<Target = Cow<'f, str>>
1.0.0 · Sourcepub fn to_mut(&mut self) -> &mut <B as ToOwned>::Owned
pub fn to_mut(&mut self) -> &mut <B as ToOwned>::Owned
Acquires a mutable reference to the owned form of the data.
Clones the data if it is not already owned.
Examples
use std::borrow::Cow;
let mut cow = Cow::Borrowed("foo");
cow.to_mut().make_ascii_uppercase();
assert_eq!(
cow,
Cow::Owned(String::from("FOO")) as Cow<'_, str>
);Trait Implementations
Sourceimpl<'f, __AsT: ?Sized> AsMut<__AsT> for Feature<'f>
impl<'f, __AsT: ?Sized> AsMut<__AsT> for Feature<'f>
Sourcefn as_mut(&mut self) -> &mut __AsT
fn as_mut(&mut self) -> &mut __AsT
Sourceimpl<'de, 'f> Deserialize<'de> for Feature<'f>
impl<'de, 'f> Deserialize<'de> for Feature<'f>
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Sourceimpl<'f> FromIterator<Feature<'f>> for FeatureSet<'f>
impl<'f> FromIterator<Feature<'f>> for FeatureSet<'f>
Sourceimpl<'f> Ord for Feature<'f>
impl<'f> Ord for Feature<'f>
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Sourceimpl<'f> PartialOrd for Feature<'f>
impl<'f> PartialOrd for Feature<'f>
impl<'f> Eq for Feature<'f>
impl<'f> StructuralPartialEq for Feature<'f>